@@ -24,9 +24,9 @@
 #include <apertium/tsx_reader.h>
 */
 
-#include <getopt.h>
+#include "getopt_long.h"
 #include <apertium/utf_converter.h>
-#include <apertium/morpho_stream.h>
+#include <apertium/file_morpho_stream.h>
 #include <apertium/tsx_reader.h>
 #include <apertium/tagger_data_hmm.h>
 #include <lttoolbox/lt_locale.h>
@@ -44,13 +44,13 @@ bool check_ambclasses;
 
 void check_file(FILE *f, const string& path) {
   if (!f) {
-    cerr<<"Error: cannot open file '"<<path<<"'\n";
+    wcerr<<"Error: cannot open file '"<<path<<"'\n";
     exit(EXIT_FAILURE);
   }
 }
 
 void readwords (FILE *is, int corpus_length) {
-  MorphoStream lexmorfo(is, true, &tagger_data_hmm);
+  FileMorphoStream lexmorfo(is, true, &tagger_data_hmm);
   TaggerWord *word=NULL;
   int nwords=0;
 
@@ -64,9 +64,9 @@ void readwords (FILE *is, int corpus_length) {
       int k=tagger_data_hmm.getOutput()[word->get_tags()];
 
       if ((k>=tagger_data_hmm.getM())||(k<0)) {
-	cerr<<"Error: Ambiguity class number out of range: "<<k<<"\n";
-	cerr<<"Word: "<<UtfConverter::toUtf8(word->get_superficial_form())<<"\n";
-	cerr<<"Ambiguity class: "<<UtfConverter::toUtf8(word->get_string_tags())<<"\n";
+	wcerr<<"Error: Ambiguity class number out of range: "<<k<<"\n";
+	wcerr<<"Word: "<<UtfConverter::toUtf8(word->get_superficial_form())<<"\n";
+	wcerr<<"Ambiguity class: "<<UtfConverter::toUtf8(word->get_string_tags())<<"\n";
       }
     }
 
@@ -77,15 +77,15 @@ void readwords (FILE *is, int corpus_length) {
 
     word=lexmorfo.get_next_word();
   }
-  cerr<<nwords<<" were readed\n";
+  wcerr<<nwords<<" were readed\n";
 }
 
 
 void help(char *name) {
-  cerr<<"USAGE:\n";
-  cerr<<name<<" {--tsxfile file.tsx | --probfile file.prob} [--clength <corpus_length>] < file.crp \n\n";
+  wcerr<<"USAGE:\n";
+  wcerr<<name<<" {--tsxfile file.tsx | --probfile file.prob} [--clength <corpus_length>] < file.crp \n\n";
 
-  cerr<<"ARGUMENTS: \n"
+  wcerr<<"ARGUMENTS: \n"
       <<"   --tsxfile|-x: Specify a tagger specification file\n"
       <<"   --probfile|-p: Specify a tagger parameter file\n"
       <<"   --clength|-l: Specify the length of the corpus to process\n";
@@ -98,19 +98,16 @@ int main(int argc, char* argv[]) {
   int corpus_length=-1;
 
   int c;
-#if HAVE_GETOPT_LONG
   int option_index=0;
-#endif
 
-  cerr<<"LOCALE: "<<setlocale(LC_ALL,"")<<"\n";
+  wcerr<<"LOCALE: "<<setlocale(LC_ALL,"")<<"\n";
 
-  cerr<<"Command line: ";
+  wcerr<<"Command line: ";
   for(int i=0; i<argc; i++)
-    cerr<<argv[i]<<" ";
-  cerr<<"\n";
+    wcerr<<argv[i]<<" ";
+  wcerr<<"\n";
 
   while (true) {
-#if HAVE_GETOPT_LONG
     static struct option long_options[] =
       {
 	{"tsxfile",  required_argument, 0, 'x'},
@@ -122,9 +119,6 @@ int main(int argc, char* argv[]) {
       };
 
     c=getopt_long(argc, argv, "x:p:l:hv",long_options, &option_index);
-#else
-    int c=getopt(argc, argv, "x:p:l:hv");
-#endif
     if (c==-1)
       break;
 
@@ -132,7 +126,7 @@ int main(int argc, char* argv[]) {
     case 'l':
       corpus_length=atoi(optarg);
       if(corpus_length<=0) {
-	cerr<<"Error: corpus length provided with --clength must be a positive integer\n";
+	wcerr<<"Error: corpus length provided with --clength must be a positive integer\n";
 	help(argv[0]);
 	exit(EXIT_FAILURE);
       }
@@ -148,8 +142,8 @@ int main(int argc, char* argv[]) {
       exit(EXIT_SUCCESS);
       break;
     case 'v':
-      cerr<<"apertium-tagger-readwords\n";
-      cerr<<"LICENSE:\n\n"
+      wcerr<<"apertium-tagger-readwords\n";
+      wcerr<<"LICENSE:\n\n"
 	  <<"   Copyright (C) 2006 Felipe Sánchez Martínez\n\n"
 	  <<"   This program is free software; you can redistribute it and/or\n"
 	  <<"   modify it under the terms of the GNU General Public License as\n"
@@ -172,33 +166,33 @@ int main(int argc, char* argv[]) {
   }
 
   if((tsxfile=="") && (probfile=="")) {
-    cerr<<"Error: You have provided neither a tagger specification file (.tsx) nor a tagger probability file (.prob). Use --tsxfile or --probfile to provide one of them\n";
+    wcerr<<"Error: You have provided neither a tagger specification file (.tsx) nor a tagger probability file (.prob). Use --tsxfile or --probfile to provide one of them\n";
     help(argv[0]);
     exit(EXIT_FAILURE);
   }
 
   if((tsxfile!="") && (probfile!="")) {
-    cerr<<"Error: You provided a tagger specification file and a tagger probability file. Only one of them can be provided, not both\n";
+    wcerr<<"Error: You provided a tagger specification file and a tagger probability file. Only one of them can be provided, not both\n";
     help(argv[0]);
     exit(EXIT_FAILURE);
   }
 
   if (tsxfile!="") {
-    cerr<<"Reading tagger specification from file '"<<tsxfile<<"' ..."<<flush;
+    wcerr<<"Reading tagger specification from file '"<<tsxfile<<"' ..."<<flush;
     TSXReader treader;
     treader.read(tsxfile);
     tagger_data_hmm=treader.getTaggerData();
-    cerr<<"done.\n";
+    wcerr<<"done.\n";
     check_ambclasses=false;
   }
 
   if (probfile!="") {
-    cerr<<"Reading tagger parameters from file '"<<probfile<<"' ..."<<flush;
+    wcerr<<"Reading tagger parameters from file '"<<probfile<<"' ..."<<flush;
     FILE* fin=NULL;
     fin=fopen(probfile.c_str(), "r");
     check_file(fin, probfile);
     tagger_data_hmm.read(fin);
-    cerr<<"done.\n";
+    wcerr<<"done.\n";
     fclose(fin);
     check_ambclasses=true;
   }
