@@ -182,15 +182,17 @@ Postchunk::readPostchunk(string const &in)
 void
 Postchunk::collectRules(xmlNode *localroot)
 {
-  for(xmlNode *i = localroot->children; i != NULL; i = i->next)
+  for(xmlNode *rule = localroot->children; rule != NULL; rule = rule->next)
   {
-    if(i->type == XML_ELEMENT_NODE)
+    if(rule->type == XML_ELEMENT_NODE)
     {
-      for(xmlNode *j = i->children; ; j = j->next)
+      size_t line = rule->line;
+      for(xmlNode *rulechild = rule->children; ; rulechild = rulechild->next)
       {
-        if(j->type == XML_ELEMENT_NODE && !xmlStrcmp(j->name, (const xmlChar *) "action"))
+        if(rulechild->type == XML_ELEMENT_NODE && !xmlStrcmp(rulechild->name, (const xmlChar *) "action"))
         {
-          rule_map.push_back(j);
+          rule_map.push_back(rulechild);
+          rule_lines.push_back(line);
           break;
         }
       }
@@ -1580,7 +1582,7 @@ Postchunk::postchunk(FILE *in, FILE *out)
     postchunk_wrapper_null_flush(in, out);
   }
 
-  int last = 0;
+  unsigned int last = input_buffer.getPos();
 
   output = out;
   ms.init(me->getInitial());
@@ -1617,12 +1619,13 @@ Postchunk::postchunk(FILE *in, FILE *out)
     int val = ms.classifyFinals(me->getFinals());
     if(val != -1)
     {
+      size_t lastrule_line = rule_lines[val-1];
       lastrule = rule_map[val-1];
       last = input_buffer.getPos();
 
       if(trace)
       {
-        wcerr << endl << L"apertium-postchunk: Rule " << val << L" ";
+        wcerr << endl << L"apertium-postchunk: Rule " << val << L" line " << lastrule_line << L" ";
         for (unsigned int ind = 0; ind < tmpword.size(); ind++)
         {
           if (ind != 0)
