@@ -39,7 +39,7 @@ using namespace std;
 class Postchunk
 {
 private:
-  
+
   Alphabet alphabet;
   MatchExe *me;
   MatchState ms;
@@ -50,6 +50,7 @@ private:
   map<string, set<string, Ltstr>, Ltstr> listslow;
   vector<xmlNode *> macro_map;
   vector<xmlNode *> rule_map;
+  vector<size_t> rule_lines;
   xmlDoc *doc;
   xmlNode *root_element;
   InterchunkWord **word;
@@ -65,12 +66,13 @@ private:
 
   xmlNode *lastrule;
   unsigned int nwords;
-  
+
   map<xmlNode *, TransferInstr> evalStringCache;
 
   bool inword;
   bool null_flush;
   bool internal_null_flush;
+  bool trace;
 
   void destroy();
   void readData(FILE *input);
@@ -117,22 +119,23 @@ private:
   static vector<wstring> getVecTags(wstring const &chunk);
   static int beginChunk(wstring const &chunk);
   static int endChunk(wstring const &chunk);
-  static void splitWordsAndBlanks(wstring const &chunk, 
+  static void splitWordsAndBlanks(wstring const &chunk,
 				  vector<wstring *> &words,
 				  vector<wstring *> &blanks);
   static wstring pseudolemma(wstring const &chunk);
   static wstring wordzero(wstring const &chunk);
-  bool checkIndex(xmlNode *element, int index, int limit);  
+  bool checkIndex(xmlNode *element, int index, int limit);
   void postchunk_wrapper_null_flush(FILE *in, FILE *out);
 
 public:
   Postchunk();
   ~Postchunk();
-  
+
   void read(string const &transferfile, string const &datafile);
   void postchunk(FILE *in, FILE *out);
   bool getNullFlush(void);
   void setNullFlush(bool null_flush);
+  void setTrace(bool trace);
 };
 
 #endif
