@@ -38,7 +38,7 @@ bool isSentenceEnd(StreamedType tok, Stream &in, bool sent_seg) {
 
 SentenceTagger::SentenceTagger() {}
 
-void SentenceTagger::tag(Stream &in, std::wostream &out, bool sent_seg) const {
+void SentenceTagger::tag(Stream &in, std::wostream &out, bool sent_seg) {
   clearBuffers();
 
   while (true) {
@@ -46,17 +46,18 @@ void SentenceTagger::tag(Stream &in, std::wostream &out, bool sent_seg) const {
     full_sent.push_back(token);
     flushes.push_back(in.flush_());
 
-    if (!token.TheLexicalUnit) {
-      if (!in.flush_()) {
+    if (token.TheLexicalUnit) {
+      lexical_sent.push_back(token);
+      if (isSentenceEnd(token, in, sent_seg)) {
         tagAndPutSentence(out);
+      }
+    } else {
+      tagAndPutSentence(out);
+      if (in.flush_()) {
+        clearBuffers();
+      } else {
         break;
       }
-      continue;
-    }
-
-    lexical_sent.push_back(token);
-    if (isSentenceEnd(token, in, sent_seg)) {
-      tagAndPutSentence(out);
     }
   }
 }
@@ -67,7 +68,7 @@ void SentenceTagger::clearBuffers() const {
   flushes.clear();
 }
 
-void SentenceTagger::tagAndPutSentence(std::wostream &out) const {
+void SentenceTagger::tagAndPutSentence(std::wostream &out) {
   TaggedSentence tagged_sent = tagSentence(lexical_sent);
   TaggedSentence::const_iterator ts_it = tagged_sent.begin();
 
