@@ -13,13 +13,13 @@
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-#ifndef STREAM_5_3_2_TAGGER_H
-#define STREAM_5_3_2_TAGGER_H
+#ifndef STREAM_5_3_1_TAGGER_H
+#define STREAM_5_3_1_TAGGER_H
 
 #include "apertium_config.h"
 
 #include "analysis.h"
-#include "basic_5_3_2_tagger.h"
+#include "basic_5_3_1_tagger.h"
 #include "basic_stream_tagger.h"
 
 #include <istream>
@@ -31,17 +31,15 @@
 #endif // ENABLE_DEBUG
 
 namespace Apertium {
-class Stream_5_3_2_Tagger : private basic_5_3_2_Tagger,
+class Stream_5_3_1_Tagger : private basic_5_3_1_Tagger,
                             public basic_StreamTagger {
 public:
-  Stream_5_3_2_Tagger(const Flags &Flags_);
+  Stream_5_3_1_Tagger(Flags &Flags_);
   void deserialise(std::istream &Serialised_basic_Tagger);
 
 private:
   long double score(const Analysis &Analysis_) const;
-  long double tokenCount_r_a(const Analysis &Analysis_) const;
-  long double tokenCount_a(const Analysis &Analysis_) const;
-  long double typeCount_a(const Analysis &Analysis_) const;
+  long double tokenCount_T(const Analysis &Analysis_) const;
 
 #if ENABLE_DEBUG
 
@@ -52,4 +50,4 @@ private:
 };
 }
 
-#endif // STREAM_5_3_2_TAGGER_H
+#endif // STREAM_5_3_1_TAGGER_H
