@@ -13,20 +13,22 @@
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, see <http://www.gnu.org/licenses/>.
 
-#ifndef STREAM_5_3_3_TAGGER_TRAINER_H
-#define STREAM_5_3_3_TAGGER_TRAINER_H
+#ifndef STREAM_5_3_1_TAGGER_TRAINER_H
+#define STREAM_5_3_1_TAGGER_TRAINER_H
+
+#include "basic_5_3_1_tagger.h"
+#include "basic_stream_tagger_trainer.h"
 
 #include "analysis.h"
-#include "basic_5_3_3_tagger.h"
-#include "basic_stream_tagger_trainer.h"
+#include "stream.h"
 
 #include <ostream>
 
 namespace Apertium {
-class Stream_5_3_3_TaggerTrainer : private basic_5_3_3_Tagger,
+class Stream_5_3_1_TaggerTrainer : private basic_5_3_1_Tagger,
                                    public basic_StreamTaggerTrainer {
 public:
-  Stream_5_3_3_TaggerTrainer(const Flags &Flags_);
+  Stream_5_3_1_TaggerTrainer(Flags &Flags_);
   void serialise(std::ostream &Serialised_basic_Tagger) const;
 
 private:
@@ -36,4 +38,4 @@ private:
 };
 }
 
-#endif // STREAM_5_3_3_TAGGER_TRAINER_H
+#endif // STREAM_5_3_1_TAGGER_TRAINER_H
