@@ -7,7 +7,7 @@ StreamTagger::~StreamTagger() {}
 
 void StreamTagger::outputLexicalUnit(
     const LexicalUnit &lexical_unit, const Optional<Analysis> analysis,
-    std::wostream &output) const {
+    std::wostream &output) {
   Stream::outputLexicalUnit(lexical_unit, analysis, output, TheFlags);
 }
 }
