@@ -240,15 +240,17 @@ Transfer::readTransfer(string const &in)
 void
 Transfer::collectRules(xmlNode *localroot)
 {
-  for(xmlNode *i = localroot->children; i != NULL; i = i->next)
+  for(xmlNode *rule = localroot->children; rule != NULL; rule = rule->next)
   {
-    if(i->type == XML_ELEMENT_NODE)
+    if(rule->type == XML_ELEMENT_NODE)
     {
-      for(xmlNode *j = i->children; ; j = j->next)
+      size_t line = rule->line;
+      for(xmlNode *rulechild = rule->children; ; rulechild = rulechild->next)
       {
-        if(j->type == XML_ELEMENT_NODE && !xmlStrcmp(j->name, (const xmlChar *) "action"))
+        if(rulechild->type == XML_ELEMENT_NODE && !xmlStrcmp(rulechild->name, (const xmlChar *) "action"))
         {
-          rule_map.push_back(j);
+          rule_map.push_back(rulechild);
+          rule_lines.push_back(line);
           break;
         }
       }
@@ -313,6 +315,13 @@ Transfer::evalString(xmlNode *element)
         }
         break;
 
+      case ti_clip_ref:
+        if(checkIndex(element, ti.getPos(), lword))
+        {
+          return word[ti.getPos()]->reference(attr_items[ti.getContent()], ti.getCondition());
+        }
+        break;
+
       case ti_linkto_sl:
         if(checkIndex(element, ti.getPos(), lword))
         {
@@ -341,6 +350,20 @@ Transfer::evalString(xmlNode *element)
         }
         break;
 
+      case ti_linkto_ref:
+        if(checkIndex(element, ti.getPos(), lword))
+        {
+          if(word[ti.getPos()]->reference(attr_items[ti.getContent()], ti.getCondition()) != "")
+          {
+            return "<" + string((char *) ti.getPointer()) + ">";
+          }
+          else
+          {
+            return "";
+          }
+        }
+        break;
+
       case ti_var:
         return variables[ti.getContent()];
 
@@ -380,6 +403,13 @@ Transfer::evalString(xmlNode *element)
         }
         break;
 
+      case ti_case_of_ref:
+        if(checkIndex(element, ti.getPos(), lword))
+        {
+          return caseOf(word[ti.getPos()]->reference(attr_items[ti.getContent()]));
+        }
+        break;
+
       default:
         return "";
     }
@@ -425,6 +455,10 @@ Transfer::evalString(xmlNode *element)
       {
         evalStringCache[element] = TransferInstr(ti_linkto_sl, (const char *) part, pos, (void *) as, queue);
       }
+      else if(!xmlStrcmp(side, (const xmlChar *) "ref"))
+      {
+        evalStringCache[element] = TransferInstr(ti_linkto_ref, (const char *) part, pos, (void *) as, queue);
+      }
       else
       {
         evalStringCache[element] = TransferInstr(ti_linkto_tl, (const char *) part, pos, (void *) as, queue);
@@ -434,6 +468,10 @@ Transfer::evalString(xmlNode *element)
     {
       evalStringCache[element] = TransferInstr(ti_clip_sl, (const char *) part, pos, NULL, queue);
     }
+    else if(!xmlStrcmp(side, (const xmlChar *) "ref"))
+    {
+      evalStringCache[element] = TransferInstr(ti_clip_ref, (const char *) part, pos, NULL, queue);
+    }
     else
     {
       evalStringCache[element] = TransferInstr(ti_clip_tl, (const char *) part, pos, NULL, queue);
@@ -504,6 +542,10 @@ Transfer::evalString(xmlNode *element)
     {
       evalStringCache[element] = TransferInstr(ti_case_of_sl, (const char *) part, pos);
     }
+    else if(!xmlStrcmp(side, (const xmlChar *) "ref"))
+    {
+      evalStringCache[element] = TransferInstr(ti_case_of_ref, (const char *) part, pos);
+    }
     else
     {
       evalStringCache[element] = TransferInstr(ti_case_of_tl, (const char *) part, pos);
@@ -939,6 +981,12 @@ Transfer::processLet(xmlNode *localroot)
         }
         return;
 
+      case ti_clip_ref:
+        if (checkIndex(leftSide, ti.getPos(), lword)) {
+          word[ti.getPos()]->setReference(attr_items[ti.getContent()], evalString(rightSide), ti.getCondition());
+        }
+        return;
+
       default:
         return;
     }
@@ -978,7 +1026,7 @@ Transfer::processLet(xmlNode *localroot)
       }
       else if(!xmlStrcmp(i->name, (const xmlChar *) "link-to"))
       {
-        as = i->children->content;
+        as = i->children->content; // TODO: set but never read
       }
     }
 
@@ -996,6 +1044,11 @@ Transfer::processLet(xmlNode *localroot)
       word[pos]->setTarget(attr_items[(const char *) part], evalString(rightSide), queue);
       evalStringCache[leftSide] = TransferInstr(ti_clip_tl, (const char *) part, pos, NULL, queue);
     }
+    else if(!xmlStrcmp(side, (const xmlChar *) "ref"))
+    {
+      word[pos]->setReference(attr_items[(const char *) part], evalString(rightSide), queue);
+      evalStringCache[leftSide] = TransferInstr(ti_clip_ref, (const char *) part, pos, NULL, queue);
+    }
     else
     {
       word[pos]->setSource(attr_items[(const char *) part], evalString(rightSide), queue);
@@ -1086,6 +1139,12 @@ Transfer::processModifyCase(xmlNode *localroot)
 				      word[pos]->source(attr_items[(const char *) part], queue));
       word[pos]->setSource(attr_items[(const char *) part], result);
     }
+    else if(!xmlStrcmp(side, (const xmlChar *) "ref"))
+    {
+      string const result = copycase(evalString(rightSide),
+              word[pos]->reference(attr_items[(const char *) part], queue));
+      word[pos]->setReference(attr_items[(const char *) part], result);
+    }
     else
     {
       string const result = copycase(evalString(rightSide),
@@ -1915,8 +1974,8 @@ Transfer::transfer(FILE *in, FILE *out)
     transfer_wrapper_null_flush(in, out);
   }
 
-  int last = 0;
-  int prev_last = 0;
+  unsigned int last = input_buffer.getPos();
+  unsigned int prev_last = last;
   int lastrule_id = -1;
   set<int> banned_rules;
 
@@ -2036,6 +2095,8 @@ Transfer::transfer(FILE *in, FILE *out)
           {
             wstring sl;
             wstring tl;
+            wstring ref;
+
             int seenSlash = 0;
             for(wstring::const_iterator it = tmpword[0]->begin(); it != tmpword[0]->end(); it++)
             {
@@ -2047,17 +2108,25 @@ Transfer::transfer(FILE *in, FILE *out)
                   it++;
                   sl.push_back(*it);
                 }
-                else
+                else if(seenSlash == 1)
                 {
                   tl.push_back(*it);
                   it++;
                   tl.push_back(*it);
                 }
+                else
+                {
+                  ref.push_back(*it);
+                  it++;
+                  ref.push_back(*it);
+                }
                 continue;
               }
               else if(*it == L'/')
               {
                 seenSlash++;
+
+                ref.clear(); //the word after the last slash is the ref
                 continue;
               }
               if(seenSlash == 0)
@@ -2068,9 +2137,9 @@ Transfer::transfer(FILE *in, FILE *out)
               {
                 tl.push_back(*it);
               }
-              else if(seenSlash > 1)
+              else
               {
-                break;
+                ref.push_back(*it);
               }
             }
             //tmpword[0]->assign(sl);
@@ -2129,13 +2198,14 @@ Transfer::transfer(FILE *in, FILE *out)
     int val = ms.classifyFinals(me->getFinals(), banned_rules);
     if(val != -1)
     {
+      size_t lastrule_line = rule_lines[val-1];
       lastrule = rule_map[val-1];
       lastrule_id = val;
       last = input_buffer.getPos();
 
       if(trace)
       {
-        wcerr << endl << L"apertium-transfer: Rule " << val << L" ";
+        wcerr << endl << L"apertium-transfer: Rule " << val << L" line " << lastrule_line << L" ";
         for (unsigned int ind = 0; ind < tmpword.size(); ind++)
         {
           if (ind != 0)
@@ -2216,12 +2286,18 @@ Transfer::applyRule()
     if(useBilingual && preBilingual == false)
     {
       tr = fstp.biltransWithQueue(*tmpword[i], false);
+      wstring refx;
+      word[i] = new TransferWord(UtfConverter::toUtf8(*tmpword[i]),
+                                 UtfConverter::toUtf8(tr.first),
+                                 UtfConverter::toUtf8(refx),
+                                 tr.second);
     }
     else if(preBilingual)
     {
-      //wcerr << "applyRule: " << *tmpword[i] << endl;
       wstring sl;
       wstring tl;
+      wstring ref;
+
       int seenSlash = 0;
       for(wstring::const_iterator it = tmpword[i]->begin(); it != tmpword[i]->end(); it++)
       {
@@ -2233,18 +2309,26 @@ Transfer::applyRule()
             it++;
             sl.push_back(*it);
           }
-          else
+          else if(seenSlash == 1)
           {
             tl.push_back(*it);
             it++;
             tl.push_back(*it);
           }
+          else
+          {
+            ref.push_back(*it);
+            it++;
+            ref.push_back(*it);
+          }
           continue;
         }
 
         if(*it == L'/')
         {
           seenSlash++;
+
+          ref.clear(); //word after last slash is ref
           continue;
         }
         if(seenSlash == 0)
@@ -2255,21 +2339,26 @@ Transfer::applyRule()
         {
           tl.push_back(*it);
         }
-        else if(seenSlash > 1)
+        else
         {
-          break;
+          ref.push_back(*it);
         }
       }
-      //tmpword[i]->assign(sl);
       tr = pair<wstring, int>(tl, false);
+      word[i] = new TransferWord(UtfConverter::toUtf8(sl),
+                                 UtfConverter::toUtf8(tr.first),
+                                 UtfConverter::toUtf8(ref),
+                                 tr.second);
     }
-    else
+    else // neither useBilingual nor preBilingual (sl==tl)
     {
       tr = pair<wstring, int>(*tmpword[i], false);
+      wstring refx;
+      word[i] = new TransferWord(UtfConverter::toUtf8(*tmpword[i]),
+                                 UtfConverter::toUtf8(tr.first),
+                                 UtfConverter::toUtf8(refx), 
+                                 tr.second);
     }
-
-    word[i] = new TransferWord(UtfConverter::toUtf8(*tmpword[i]),
-			       UtfConverter::toUtf8(tr.first), tr.second);
   }
 
   words_to_consume = processRule(lastrule);
